@@ -5,21 +5,12 @@ import autolens.plot as aplt
 """
 This script simulates `Imaging` of a strong lens where:
 
- - The lens `Galaxy`'s `MassProfile` is a *SphericalIsothermal*.
+ - The lens total mass distribution is a *SphericalIsothermal*.
  - The source `Galaxy`'s `LightProfile` is a *SphericalExponential*.
 
 This dataset is used in chapter 2, tutorials 1-3.
 """
 
-# %%
-"""Use the WORKSPACE environment variable to determine the path to the `autolens_workspace`."""
-
-# %%
-import os
-
-workspace_path = os.environ["WORKSPACE"]
-print("Workspace Path: ", workspace_path)
-
 """
 The `dataset_type` describes the type of data being simulated (in this case, `Imaging` data) and `dataset_name` 
 gives it a descriptive name. They define the folder the dataset is output to on your hard-disk:
@@ -32,10 +23,10 @@ dataset_type = "chapter_4"
 dataset_name = "mass_sie_x2__source_sersic"
 
 """
-Create the path where the dataset will be output, which in this case is:
+Returns the path where the dataset will be output, which in this case is:
 `/autolens_workspace/howtolens/dataset/chapter_2/mass_sis__source_exp/`
 """
-dataset_path = f"{workspace_path}/howtolens/dataset/{dataset_type}/{dataset_name}"
+dataset_path = f"dataset/howtolens/{dataset_type}/{dataset_name}"
 
 """
 For simulating an image of a strong lens, we recommend using a GridIterate object. This represents a grid of $(y,x)$ 
@@ -59,18 +50,15 @@ psf = al.Kernel.from_gaussian(
 )
 
 """
-To simulate the `Imaging` dataset we first create a simulator, which defines the expoosure time, background sky,
+To simulate the `Imaging` dataset we first create a simulator, which defines the exposure time, background sky,
 noise levels and psf of the dataset that is simulated.
 """
 simulator = al.SimulatorImaging(
-    exposure_time_map=al.Array.full(fill_value=300.0, shape_2d=grid.shape_2d),
-    psf=psf,
-    background_sky_map=al.Array.full(fill_value=0.1, shape_2d=grid.shape_2d),
-    add_noise=True,
+    exposure_time=300.0, psf=psf, background_sky_level=0.1, add_poisson_noise=True
 )
 
 """
-Setup the two lens galaxies with `EllipticalIsothermal` `MassProfile`'s and source galaxy light (_EllipticalSersic_) 
+Setup the two lens galaxies with `EllipticalIsothermal` `MassProfile`'s and source galaxy light (`EllipticalSersic`) 
 for this simulated lens.
 
 For lens modeling, defining ellipticity in terms of the  `elliptical_comps` improves the model-fitting procedure.
@@ -98,7 +86,7 @@ lens_galaxy_1 = al.Galaxy(
 
 source_galaxy_0 = al.Galaxy(
     redshift=1.0,
-    sersic=al.lp.EllipticalSersic(
+    bulge=al.lp.EllipticalSersic(
         centre=(0.05, 0.05),
         elliptical_comps=(0.1, 0.0),
         intensity=0.2,
